Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(39)

Unified Diff: net/data/verify_certificate_chain_unittest/generate-target-has-pathlen-but-not-ca.py

Issue 2233233002: Refactor some certificate verification tests in preparation to adding (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@trust_anchor
Patch Set: fix Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/data/verify_certificate_chain_unittest/generate-target-has-pathlen-but-not-ca.py
diff --git a/net/data/verify_certificate_chain_unittest/generate-target-has-pathlen-but-not-ca.py b/net/data/verify_certificate_chain_unittest/generate-target-has-pathlen-but-not-ca.py
index 558e98cf8e813b72fcc57256fada20f18ab895ce..abe6809125b8d0bcdcb7fa934a57d9ed2cde5ccf 100755
--- a/net/data/verify_certificate_chain_unittest/generate-target-has-pathlen-but-not-ca.py
+++ b/net/data/verify_certificate_chain_unittest/generate-target-has-pathlen-but-not-ca.py
@@ -9,7 +9,7 @@ expected to fail, since pathlen should only be set for CAs."""
import common
# Self-signed root certificate (part of trust store).
root = common.create_self_signed_root_certificate('Root')
# Intermediate certificate.
@@ -22,7 +22,7 @@ target.get_extensions().set_property('basicConstraints',
chain = [target, intermediate]
-trusted = [root]
+trusted = common.TrustAnchor(root, constrained=False)
time = common.DEFAULT_TIME
verify_result = False
@@ -9,7 +9,7 @@ expected to fail, since pathlen should only be set for CAs."""
import common
-# Self-signed root certificate (part of trust store).
+# Self-signed root certificate (used as trust anchor).
root = common.create_self_signed_root_certificate('Root')
# Intermediate certificate.

Powered by Google App Engine
This is Rietveld 408576698